Nesta página

zabbix_sender

ZABBIX_SENDER(1)            Manual de comandos gerais           ZABBIX_SENDER(1)

NOME
       zabbix_sender - utilitário de envio do Zabbix

SINOPSE
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host -k key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect cert --tls-ca-file CA-file [--tls-crl-file CRL-file]
       [--tls-server-cert-issuer cert-issuer] [--tls-server-cert-subject
       cert-subject] --tls-cert-file cert-file --tls-key-file key-file
       [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k key -o
       value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect cert --tls-ca-file CA-file [--tls-crl-file
       CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k
       key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string]
       [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender -h
       zabbix_sender -V

DESCRIÇÃO
       zabbix_sender é um utilitário de linha de comando para enviar dados de
       monitoramento ao Zabbix server ou proxy. No Zabbix server, deve ser
       criado um item do tipo Zabbix trapper com a chave correspondente.
       Observe que os valores recebidos somente serão aceitos de hosts
       especificados no campo Allowed hosts desse item.

OPÇÕES
       -c, --config config-file
              Usa config-file. O Zabbix sender lê os detalhes do server no
              arquivo de configuração do agentd. Por padrão, o Zabbix sender
              não lê nenhum arquivo de configuração. Somente os parâmetros
              Hostname, ServerActive, SourceIP, TLSConnect, TLSCAFile,
              TLSCRLFile, TLSServerCertIssuer, TLSServerCertSubject,
              TLSCertFile, TLSKeyFile, TLSPSKIdentity e TLSPSKFile são
              compatíveis. O Hostname definido por meio do parâmetro
              HostnameItem não será obtido; nesse caso, o hostname deve ser
              especificado pela linha de comando (consulte a opção -s). Todos
              os endereços definidos no parâmetro de configuração ServerActive
              do agent são usados para enviar dados. Se o envio de dados em
              lote falhar para um endereço, os lotes seguintes não serão
              enviados para esse endereço.

       -z, --zabbix-server server
              Nome do host ou endereço IP do Zabbix server. Se um host for
              monitorado por um proxy, deverá ser usado o nome do host ou
              endereço IP do proxy. Quando usado junto com --config, substitui
              as entradas do parâmetro ServerActive especificadas no arquivo
              de configuração do agentd.

       -p, --port port
              Especifica o número da porta em que o Zabbix server trapper está
              em execução no server. O padrão é 10051. Quando usado junto com
              --config, substitui as entradas de porta do parâmetro
              ServerActive especificadas no arquivo de configuração do agentd.

       -I, --source-address IP-address
              Especifica o endereço IP de origem. Quando usado junto com
              --config, substitui o parâmetro SourceIP especificado no arquivo
              de configuração do agentd.

       -t, --timeout seconds
              Especifica o tempo limite. Intervalo válido: 1-300 segundos
              (padrão: 60)

       -s, --host host
              Especifica o nome do host ao qual o item pertence (conforme
              registrado no frontend do Zabbix). O endereço IP e o nome DNS do
              host não funcionarão. Quando usado junto com --config, substitui
              o parâmetro Hostname especificado no arquivo de configuração do
              agentd.

       -k, --key key
              Especifica a chave do item para a qual o valor será enviado.

       -o, --value value
              Especifica o valor do item.

       -i, --input-file input-file
              Carrega os valores do arquivo de entrada. Especifique - como
              <input-file> para ler os valores da entrada padrão. Cada linha do
              arquivo contém, separados por espaços em branco:
              <hostname> <key> <value>. Cada valor deve ser especificado em
              sua própria linha. Cada linha deve conter 3 entradas separadas
              por espaços em branco: <hostname> <key> <value>, em que
              "hostname" é o nome do host monitorado conforme registrado no
              frontend do Zabbix, "key" é a chave do item de destino e
              "value" é o valor a ser enviado. Especifique - como <hostname>
              para usar o hostname do arquivo de configuração do agent ou do
              argumento --host.

              Exemplo de uma linha de um arquivo de entrada:

               "Linux DB3" db.connections 43

              O tipo de valor deve estar definido corretamente na configuração
              do item no frontend do Zabbix. O Zabbix sender enviará até 250
              valores em uma conexão. O conteúdo do arquivo de entrada deve
              estar na codificação UTF-8. Todos os valores do arquivo de
              entrada são enviados em ordem sequencial, de cima para baixo. As
              entradas devem ser formatadas de acordo com as seguintes regras:

                     • Entradas entre aspas e sem aspas são compatíveis.

                     • As aspas duplas são o caractere de delimitação.

                     • Entradas com espaços em branco devem estar entre aspas.

                     • Os caracteres de aspas duplas e barra invertida dentro
                       de uma entrada entre aspas devem ser escapados com uma
                       barra invertida.

                     • O escape não é compatível com entradas sem aspas.

                     • Sequências de escape de avanço de linha (\n) são
                       compatíveis com strings entre aspas.

                     • As sequências de escape de avanço de linha são removidas
                       do final de uma entrada.

       -T, --with-timestamps
              Esta opção somente pode ser usada com a opção --input-file.

              Cada linha do arquivo de entrada deve conter 4 entradas separadas
              por espaços em branco: <hostname> <key> <timestamp> <value>. O
              timestamp deve ser especificado no formato de timestamp Unix. Se
              o item de destino tiver triggers que façam referência a ele,
              todos os timestamps deverão estar em ordem crescente; caso
              contrário, o cálculo do evento não estará correto.

              Exemplo de uma linha de um arquivo de entrada:

               "Linux DB3" db.connections 1429533600 43

              Para obter mais detalhes, consulte a opção --input-file.

              Se um valor com timestamp for enviado para um host que esteja em
              um período de manutenção do tipo “no data”, esse valor será
              descartado; no entanto, é possível enviar um valor com timestamp
              para um período de manutenção expirado, e ele será aceito.

       -N, --with-ns
              Esta opção somente pode ser usada com a opção --with-timestamps.

              Cada linha do arquivo de entrada deve conter 5 entradas separadas
              por espaços em branco: <hostname> <key> <timestamp> <ns> <value>.

              Exemplo de uma linha de um arquivo de entrada:

               "Linux DB3" db.connections 1429533600 7402561 43

              Para obter mais detalhes, consulte a opção --input-file.

       -r, --real-time
              Envia os valores um por um assim que são recebidos. Isso pode ser
              usado ao ler a partir da entrada padrão.

       --tls-connect value
              Como se conectar ao server ou proxy. Valores:

                   unencrypted
                               conecta sem criptografia (padrão)

                   psk         conecta usando TLS e uma chave pré-compartilhada

                   cert        conecta usando TLS e um certificado

       --tls-ca-file CA-file
              Nome de caminho completo de um arquivo que contém os certificados
              da CA de nível superior para verificação do certificado do peer.

       --tls-crl-file CRL-file
              Nome de caminho completo de um arquivo que contém certificados
              revogados.

       --tls-server-cert-issuer cert-issuer
              Emissor de certificado do server permitido.

       --tls-server-cert-subject cert-subject
              Assunto do certificado do server permitido.

       --tls-cert-file cert-file
              Nome de caminho completo de um arquivo que contém o certificado
              ou a cadeia de certificados.

       --tls-key-file key-file
              Nome de caminho completo de um arquivo que contém a chave privada.

       --tls-psk-identity PSK-identity
              String de identidade PSK.

       --tls-psk-file PSK-file
              Nome de caminho completo de um arquivo que contém a chave
              pré-compartilhada.

       --tls-cipher13 cipher-string
              String de cifras para OpenSSL 1.1.1 ou mais recente para TLS 1.3.
              Substitui os critérios padrão de seleção do conjunto de cifras.
              Esta opção não está disponível se a versão do OpenSSL for
              inferior a 1.1.1.

       --tls-cipher cipher-string
              String de prioridade do GnuTLS (para TLS 1.2 e superior) ou
              string de cifras do OpenSSL (somente para TLS 1.2). Substitui os
              critérios padrão de seleção do conjunto de cifras.

       -v, --verbose
              Modo detalhado; use -vv para obter mais detalhes.

       -h, --help
              Exibe esta ajuda e sai.

       -V, --version
              Exibe informações da versão e sai.

STATUS DE SAÍDA
       O status de saída será 0 se os valores tiverem sido enviados e todos
       tiverem sido processados com sucesso pelo server. Se os dados tiverem
       sido enviados, mas o processamento de pelo menos um dos valores tiver
       falhado, o status de saída será 2. Se o envio dos dados tiver falhado,
       o status de saída será 1.

EXEMPLOS
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              Envia 342.45 como o valor do item mysql.queries do host
              monitorado. Usa o host monitorado e o Zabbix server definidos no
              arquivo de configuração do agent.

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              Envia 342.45 como o valor do item mysql.queries do host
              Monitored Host usando o Zabbix server definido no arquivo de
              configuração do agent.

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              Envia os valores do arquivo data_values.txt para o Zabbix server
              com o IP 192.168.1.113. Os nomes dos hosts e as chaves são
              definidos no arquivo.

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              Envia um valor com timestamp da linha de comando para o Zabbix
              server especificado no arquivo de configuração do agent. O hífen
              nos dados de entrada indica que o hostname também deve ser usado
              do mesmo arquivo de configuração.

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              Envia um valor vazio de um item para o Zabbix server com o
              endereço IP 192.168.1.113 na porta 10000, a partir da linha de
              comando. Os valores vazios devem ser indicados por aspas duplas
              vazias.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              Envia 342.45 como o valor do item mysql.queries no host
              Monitored Host para o server com o IP 192.168.1.113 usando TLS
              com certificado.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              Envia 342.45 como o valor do item mysql.queries no host Monitored
              Host para o server com o IP 192.168.1.113 usando TLS com uma
              chave pré-compartilhada (PSK).

VEJA TAMBÉM
       Documentação

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)